# Cleaning Up

In this lab you will delete the compute resources created during this tutorial.

## Compute Instances

Delete the controller and worker compute instances:

```
for instance in controller-0 controller-1 controller-2 worker-0 worker-1 worker-2; do
  NODE_ID=$(oci compute instance list --lifecycle-state RUNNING --display-name $instance \
    | jq -r .data[0].id)
  oci compute instance terminate --instance-id $NODE_ID --wait-for-state TERMINATED --force
done
```

## Networking

Delete the Load Balancer:

```
{
  LOAD_BALANCER_ID=$(oci lb load-balancer list --display-name kubernetes-the-hard-way | jq -r .data[0].id)
  oci lb load-balancer delete --load-balancer-id $LOAD_BALANCER_ID --force --wait-for-state SUCCEEDED
}
```

Delete all resources within the `kubernetes-the-hard-way` VCN:

```
{
  VCN_ID=$(oci network vcn list --display-name kubernetes-the-hard-way | jq -r .data[0].id)

  SUBNET_ID=$(oci network subnet list --display-name kubernetes --vcn-id $VCN_ID \
    | jq -r .data[0].id)
  oci network subnet delete --subnet-id $SUBNET_ID --force

  ROUTE_TABLE_ID=$(oci network route-table list --display-name kubernetes-the-hard-way \
    --vcn-id $VCN_ID | jq -r .data[0].id)
  oci network route-table delete --rt-id $ROUTE_TABLE_ID --force

  INTERNET_GATEWAY_ID=$(oci network internet-gateway list --display-name kubernetes-the-hard-way \
    --vcn-id $VCN_ID | jq -r .data[0].id)
  oci network internet-gateway delete --ig-id $INTERNET_GATEWAY_ID --force

  SECURITY_LIST_ID=$(oci network security-list list --vcn-id $VCN_ID --display-name intra-vcn \
    | jq -r .data[0].id)
  oci network security-list delete --security-list-id $SECURITY_LIST_ID --force
  
  SECURITY_LIST_ID=$(oci network security-list list --vcn-id $VCN_ID --display-name load-balancer \
    | jq -r .data[0].id)
  oci network security-list delete --security-list-id $SECURITY_LIST_ID --force
  
  SECURITY_LIST_ID=$(oci network security-list list --vcn-id $VCN_ID --display-name worker \
    | jq -r .data[0].id)
  oci network security-list delete --security-list-id $SECURITY_LIST_ID --force
}
```

And the VCN itself:

```
oci network vcn delete --vcn-id $VCN_ID --force
```

Finally, remove the artifacts generated by our shell helper functions:

```
rm -rf .kubernetes-the-hard-way
```
